import reflex as rx

class HiAcademicCap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiAcademicCap"


class HiAdjustmentsHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiAdjustmentsHorizontal"


class HiAdjustmentsVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiAdjustmentsVertical"


class HiArchiveBoxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArchiveBoxArrowDown"


class HiArchiveBoxXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArchiveBoxXMark"


class HiArchiveBox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArchiveBox"


class HiArrowDownCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownCircle"


class HiArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownLeft"


class HiArrowDownOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownOnSquareStack"


class HiArrowDownOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownOnSquare"


class HiArrowDownRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownRight"


class HiArrowDownTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDownTray"


class HiArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowDown"


class HiArrowLeftCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLeftCircle"


class HiArrowLeftOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLeftOnRectangle"


class HiArrowLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLeft"


class HiArrowLongDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLongDown"


class HiArrowLongLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLongLeft"


class HiArrowLongRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLongRight"


class HiArrowLongUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowLongUp"


class HiArrowPathRoundedSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowPathRoundedSquare"


class HiArrowPath(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowPath"


class HiArrowRightCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowRightCircle"


class HiArrowRightOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowRightOnRectangle"


class HiArrowRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowRight"


class HiArrowSmallDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowSmallDown"


class HiArrowSmallLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowSmallLeft"


class HiArrowSmallRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowSmallRight"


class HiArrowSmallUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowSmallUp"


class HiArrowTopRightOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowTopRightOnSquare"


class HiArrowTrendingDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowTrendingDown"


class HiArrowTrendingUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowTrendingUp"


class HiArrowUpCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpCircle"


class HiArrowUpLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpLeft"


class HiArrowUpOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpOnSquareStack"


class HiArrowUpOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpOnSquare"


class HiArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpRight"


class HiArrowUpTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUpTray"


class HiArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUp"


class HiArrowUturnDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUturnDown"


class HiArrowUturnLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUturnLeft"


class HiArrowUturnRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUturnRight"


class HiArrowUturnUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowUturnUp"


class HiArrowsPointingIn(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowsPointingIn"


class HiArrowsPointingOut(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowsPointingOut"


class HiArrowsRightLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowsRightLeft"


class HiArrowsUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiArrowsUpDown"


class HiAtSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiAtSymbol"


class HiBackspace(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBackspace"


class HiBackward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBackward"


class HiBanknotes(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBanknotes"


class HiBars2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars2"


class HiBars3BottomLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars3BottomLeft"


class HiBars3BottomRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars3BottomRight"


class HiBars3CenterLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars3CenterLeft"


class HiBars3(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars3"


class HiBars4(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBars4"


class HiBarsArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBarsArrowDown"


class HiBarsArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBarsArrowUp"


class HiBattery0(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBattery0"


class HiBattery100(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBattery100"


class HiBattery50(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBattery50"


class HiBeaker(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBeaker"


class HiBellAlert(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBellAlert"


class HiBellSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBellSlash"


class HiBellSnooze(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBellSnooze"


class HiBell(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBell"


class HiBoltSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBoltSlash"


class HiBolt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBolt"


class HiBookOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBookOpen"


class HiBookmarkSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBookmarkSlash"


class HiBookmarkSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBookmarkSquare"


class HiBookmark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBookmark"


class HiBriefcase(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBriefcase"


class HiBugAnt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBugAnt"


class HiBuildingLibrary(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBuildingLibrary"


class HiBuildingOffice2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBuildingOffice2"


class HiBuildingOffice(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBuildingOffice"


class HiBuildingStorefront(rx.Component):
    library = "react-icons/hi2"
    tag = "HiBuildingStorefront"


class HiCake(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCake"


class HiCalculator(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCalculator"


class HiCalendarDays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCalendarDays"


class HiCalendar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCalendar"


class HiCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCamera"


class HiChartBarSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChartBarSquare"


class HiChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChartBar"


class HiChartPie(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChartPie"


class HiChatBubbleBottomCenterText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleBottomCenterText"


class HiChatBubbleBottomCenter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleBottomCenter"


class HiChatBubbleLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleLeftEllipsis"


class HiChatBubbleLeftRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleLeftRight"


class HiChatBubbleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleLeft"


class HiChatBubbleOvalLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleOvalLeftEllipsis"


class HiChatBubbleOvalLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChatBubbleOvalLeft"


class HiCheckBadge(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCheckBadge"


class HiCheckCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCheckCircle"


class HiCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCheck"


class HiChevronDoubleDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronDoubleDown"


class HiChevronDoubleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronDoubleLeft"


class HiChevronDoubleRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronDoubleRight"


class HiChevronDoubleUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronDoubleUp"


class HiChevronDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronDown"


class HiChevronLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronLeft"


class HiChevronRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronRight"


class HiChevronUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronUpDown"


class HiChevronUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiChevronUp"


class HiCircleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCircleStack"


class HiClipboardDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiClipboardDocumentCheck"


class HiClipboardDocumentList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiClipboardDocumentList"


class HiClipboardDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiClipboardDocument"


class HiClipboard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiClipboard"


class HiClock(rx.Component):
    library = "react-icons/hi2"
    tag = "HiClock"


class HiCloudArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCloudArrowDown"


class HiCloudArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCloudArrowUp"


class HiCloud(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCloud"


class HiCodeBracketSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCodeBracketSquare"


class HiCodeBracket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCodeBracket"


class HiCog6Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCog6Tooth"


class HiCog8Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCog8Tooth"


class HiCog(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCog"


class HiCommandLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCommandLine"


class HiComputerDesktop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiComputerDesktop"


class HiCpuChip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCpuChip"


class HiCreditCard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCreditCard"


class HiCubeTransparent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCubeTransparent"


class HiCube(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCube"


class HiCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyBangladeshi"


class HiCurrencyDollar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyDollar"


class HiCurrencyEuro(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyEuro"


class HiCurrencyPound(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyPound"


class HiCurrencyRupee(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyRupee"


class HiCurrencyYen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCurrencyYen"


class HiCursorArrowRays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCursorArrowRays"


class HiCursorArrowRipple(rx.Component):
    library = "react-icons/hi2"
    tag = "HiCursorArrowRipple"


class HiDevicePhoneMobile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDevicePhoneMobile"


class HiDeviceTablet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDeviceTablet"


class HiDocumentArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentArrowDown"


class HiDocumentArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentArrowUp"


class HiDocumentChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentChartBar"


class HiDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentCheck"


class HiDocumentDuplicate(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentDuplicate"


class HiDocumentMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentMagnifyingGlass"


class HiDocumentMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentMinus"


class HiDocumentPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentPlus"


class HiDocumentText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocumentText"


class HiDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiDocument"


class HiEllipsisHorizontalCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEllipsisHorizontalCircle"


class HiEllipsisHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEllipsisHorizontal"


class HiEllipsisVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEllipsisVertical"


class HiEnvelopeOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEnvelopeOpen"


class HiEnvelope(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEnvelope"


class HiExclamationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiExclamationCircle"


class HiExclamationTriangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiExclamationTriangle"


class HiEyeDropper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEyeDropper"


class HiEyeSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEyeSlash"


class HiEye(rx.Component):
    library = "react-icons/hi2"
    tag = "HiEye"


class HiFaceFrown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFaceFrown"


class HiFaceSmile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFaceSmile"


class HiFilm(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFilm"


class HiFingerPrint(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFingerPrint"


class HiFire(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFire"


class HiFlag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFlag"


class HiFolderArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFolderArrowDown"


class HiFolderMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFolderMinus"


class HiFolderOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFolderOpen"


class HiFolderPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFolderPlus"


class HiFolder(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFolder"


class HiForward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiForward"


class HiFunnel(rx.Component):
    library = "react-icons/hi2"
    tag = "HiFunnel"


class HiGif(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGif"


class HiGiftTop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGiftTop"


class HiGift(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGift"


class HiGlobeAlt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGlobeAlt"


class HiGlobeAmericas(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGlobeAmericas"


class HiGlobeAsiaAustralia(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGlobeAsiaAustralia"


class HiGlobeEuropeAfrica(rx.Component):
    library = "react-icons/hi2"
    tag = "HiGlobeEuropeAfrica"


class HiHandRaised(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHandRaised"


class HiHandThumbDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHandThumbDown"


class HiHandThumbUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHandThumbUp"


class HiHashtag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHashtag"


class HiHeart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHeart"


class HiHomeModern(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHomeModern"


class HiHome(rx.Component):
    library = "react-icons/hi2"
    tag = "HiHome"


class HiIdentification(rx.Component):
    library = "react-icons/hi2"
    tag = "HiIdentification"


class HiInboxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiInboxArrowDown"


class HiInboxStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiInboxStack"


class HiInbox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiInbox"


class HiInformationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiInformationCircle"


class HiKey(rx.Component):
    library = "react-icons/hi2"
    tag = "HiKey"


class HiLanguage(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLanguage"


class HiLifebuoy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLifebuoy"


class HiLightBulb(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLightBulb"


class HiLink(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLink"


class HiListBullet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiListBullet"


class HiLockClosed(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLockClosed"


class HiLockOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiLockOpen"


class HiMagnifyingGlassCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMagnifyingGlassCircle"


class HiMagnifyingGlassMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMagnifyingGlassMinus"


class HiMagnifyingGlassPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMagnifyingGlassPlus"


class HiMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMagnifyingGlass"


class HiMapPin(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMapPin"


class HiMap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMap"


class HiMegaphone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMegaphone"


class HiMicrophone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMicrophone"


class HiMinusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMinusCircle"


class HiMinusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMinusSmall"


class HiMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMinus"


class HiMoon(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMoon"


class HiMusicalNote(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMusicalNote"


class HiNewspaper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiNewspaper"


class HiNoSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiNoSymbol"


class HiPaintBrush(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPaintBrush"


class HiPaperAirplane(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPaperAirplane"


class HiPaperClip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPaperClip"


class HiPauseCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPauseCircle"


class HiPause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPause"


class HiPencilSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPencilSquare"


class HiPencil(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPencil"


class HiPhoneArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPhoneArrowDownLeft"


class HiPhoneArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPhoneArrowUpRight"


class HiPhoneXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPhoneXMark"


class HiPhone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPhone"


class HiPhoto(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPhoto"


class HiPlayCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlayCircle"


class HiPlayPause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlayPause"


class HiPlay(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlay"


class HiPlusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlusCircle"


class HiPlusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlusSmall"


class HiPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPlus"


class HiPower(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPower"


class HiPresentationChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPresentationChartBar"


class HiPresentationChartLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPresentationChartLine"


class HiPrinter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPrinter"


class HiPuzzlePiece(rx.Component):
    library = "react-icons/hi2"
    tag = "HiPuzzlePiece"


class HiQrCode(rx.Component):
    library = "react-icons/hi2"
    tag = "HiQrCode"


class HiQuestionMarkCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiQuestionMarkCircle"


class HiQueueList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiQueueList"


class HiRadio(rx.Component):
    library = "react-icons/hi2"
    tag = "HiRadio"


class HiReceiptPercent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiReceiptPercent"


class HiReceiptRefund(rx.Component):
    library = "react-icons/hi2"
    tag = "HiReceiptRefund"


class HiRectangleGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiRectangleGroup"


class HiRectangleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiRectangleStack"


class HiRocketLaunch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiRocketLaunch"


class HiRss(rx.Component):
    library = "react-icons/hi2"
    tag = "HiRss"


class HiScale(rx.Component):
    library = "react-icons/hi2"
    tag = "HiScale"


class HiScissors(rx.Component):
    library = "react-icons/hi2"
    tag = "HiScissors"


class HiServerStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiServerStack"


class HiServer(rx.Component):
    library = "react-icons/hi2"
    tag = "HiServer"


class HiShare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiShare"


class HiShieldCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiShieldCheck"


class HiShieldExclamation(rx.Component):
    library = "react-icons/hi2"
    tag = "HiShieldExclamation"


class HiShoppingBag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiShoppingBag"


class HiShoppingCart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiShoppingCart"


class HiSignalSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSignalSlash"


class HiSignal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSignal"


class HiSparkles(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSparkles"


class HiSpeakerWave(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSpeakerWave"


class HiSpeakerXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSpeakerXMark"


class HiSquare2Stack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSquare2Stack"


class HiSquare3Stack3D(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSquare3Stack3D"


class HiSquares2X2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSquares2X2"


class HiSquaresPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSquaresPlus"


class HiStar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiStar"


class HiStopCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiStopCircle"


class HiStop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiStop"


class HiSun(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSun"


class HiSwatch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiSwatch"


class HiTableCells(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTableCells"


class HiTag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTag"


class HiTicket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTicket"


class HiTrash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTrash"


class HiTrophy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTrophy"


class HiTruck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTruck"


class HiTv(rx.Component):
    library = "react-icons/hi2"
    tag = "HiTv"


class HiUserCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUserCircle"


class HiUserGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUserGroup"


class HiUserMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUserMinus"


class HiUserPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUserPlus"


class HiUser(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUser"


class HiUsers(rx.Component):
    library = "react-icons/hi2"
    tag = "HiUsers"


class HiVariable(rx.Component):
    library = "react-icons/hi2"
    tag = "HiVariable"


class HiVideoCameraSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiVideoCameraSlash"


class HiVideoCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiVideoCamera"


class HiViewColumns(rx.Component):
    library = "react-icons/hi2"
    tag = "HiViewColumns"


class HiViewfinderCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiViewfinderCircle"


class HiWallet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiWallet"


class HiWifi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiWifi"


class HiWindow(rx.Component):
    library = "react-icons/hi2"
    tag = "HiWindow"


class HiWrenchScrewdriver(rx.Component):
    library = "react-icons/hi2"
    tag = "HiWrenchScrewdriver"


class HiWrench(rx.Component):
    library = "react-icons/hi2"
    tag = "HiWrench"


class HiXCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiXCircle"


class HiXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiXMark"


class HiOutlineAcademicCap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineAcademicCap"


class HiOutlineAdjustmentsHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineAdjustmentsHorizontal"


class HiOutlineAdjustmentsVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineAdjustmentsVertical"


class HiOutlineArchiveBoxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArchiveBoxArrowDown"


class HiOutlineArchiveBoxXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArchiveBoxXMark"


class HiOutlineArchiveBox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArchiveBox"


class HiOutlineArrowDownCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownCircle"


class HiOutlineArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownLeft"


class HiOutlineArrowDownOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownOnSquareStack"


class HiOutlineArrowDownOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownOnSquare"


class HiOutlineArrowDownRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownRight"


class HiOutlineArrowDownTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDownTray"


class HiOutlineArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowDown"


class HiOutlineArrowLeftCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLeftCircle"


class HiOutlineArrowLeftOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLeftOnRectangle"


class HiOutlineArrowLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLeft"


class HiOutlineArrowLongDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLongDown"


class HiOutlineArrowLongLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLongLeft"


class HiOutlineArrowLongRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLongRight"


class HiOutlineArrowLongUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowLongUp"


class HiOutlineArrowPathRoundedSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowPathRoundedSquare"


class HiOutlineArrowPath(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowPath"


class HiOutlineArrowRightCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowRightCircle"


class HiOutlineArrowRightOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowRightOnRectangle"


class HiOutlineArrowRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowRight"


class HiOutlineArrowSmallDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowSmallDown"


class HiOutlineArrowSmallLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowSmallLeft"


class HiOutlineArrowSmallRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowSmallRight"


class HiOutlineArrowSmallUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowSmallUp"


class HiOutlineArrowTopRightOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowTopRightOnSquare"


class HiOutlineArrowTrendingDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowTrendingDown"


class HiOutlineArrowTrendingUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowTrendingUp"


class HiOutlineArrowUpCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpCircle"


class HiOutlineArrowUpLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpLeft"


class HiOutlineArrowUpOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpOnSquareStack"


class HiOutlineArrowUpOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpOnSquare"


class HiOutlineArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpRight"


class HiOutlineArrowUpTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUpTray"


class HiOutlineArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUp"


class HiOutlineArrowUturnDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUturnDown"


class HiOutlineArrowUturnLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUturnLeft"


class HiOutlineArrowUturnRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUturnRight"


class HiOutlineArrowUturnUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowUturnUp"


class HiOutlineArrowsPointingIn(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowsPointingIn"


class HiOutlineArrowsPointingOut(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowsPointingOut"


class HiOutlineArrowsRightLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowsRightLeft"


class HiOutlineArrowsUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineArrowsUpDown"


class HiOutlineAtSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineAtSymbol"


class HiOutlineBackspace(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBackspace"


class HiOutlineBackward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBackward"


class HiOutlineBanknotes(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBanknotes"


class HiOutlineBars2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars2"


class HiOutlineBars3BottomLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars3BottomLeft"


class HiOutlineBars3BottomRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars3BottomRight"


class HiOutlineBars3CenterLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars3CenterLeft"


class HiOutlineBars3(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars3"


class HiOutlineBars4(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBars4"


class HiOutlineBarsArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBarsArrowDown"


class HiOutlineBarsArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBarsArrowUp"


class HiOutlineBattery0(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBattery0"


class HiOutlineBattery100(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBattery100"


class HiOutlineBattery50(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBattery50"


class HiOutlineBeaker(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBeaker"


class HiOutlineBellAlert(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBellAlert"


class HiOutlineBellSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBellSlash"


class HiOutlineBellSnooze(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBellSnooze"


class HiOutlineBell(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBell"


class HiOutlineBoltSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBoltSlash"


class HiOutlineBolt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBolt"


class HiOutlineBookOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBookOpen"


class HiOutlineBookmarkSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBookmarkSlash"


class HiOutlineBookmarkSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBookmarkSquare"


class HiOutlineBookmark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBookmark"


class HiOutlineBriefcase(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBriefcase"


class HiOutlineBugAnt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBugAnt"


class HiOutlineBuildingLibrary(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBuildingLibrary"


class HiOutlineBuildingOffice2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBuildingOffice2"


class HiOutlineBuildingOffice(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBuildingOffice"


class HiOutlineBuildingStorefront(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineBuildingStorefront"


class HiOutlineCake(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCake"


class HiOutlineCalculator(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCalculator"


class HiOutlineCalendarDays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCalendarDays"


class HiOutlineCalendar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCalendar"


class HiOutlineCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCamera"


class HiOutlineChartBarSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChartBarSquare"


class HiOutlineChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChartBar"


class HiOutlineChartPie(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChartPie"


class HiOutlineChatBubbleBottomCenterText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleBottomCenterText"


class HiOutlineChatBubbleBottomCenter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleBottomCenter"


class HiOutlineChatBubbleLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleLeftEllipsis"


class HiOutlineChatBubbleLeftRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleLeftRight"


class HiOutlineChatBubbleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleLeft"


class HiOutlineChatBubbleOvalLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleOvalLeftEllipsis"


class HiOutlineChatBubbleOvalLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChatBubbleOvalLeft"


class HiOutlineCheckBadge(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCheckBadge"


class HiOutlineCheckCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCheckCircle"


class HiOutlineCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCheck"


class HiOutlineChevronDoubleDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronDoubleDown"


class HiOutlineChevronDoubleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronDoubleLeft"


class HiOutlineChevronDoubleRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronDoubleRight"


class HiOutlineChevronDoubleUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronDoubleUp"


class HiOutlineChevronDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronDown"


class HiOutlineChevronLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronLeft"


class HiOutlineChevronRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronRight"


class HiOutlineChevronUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronUpDown"


class HiOutlineChevronUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineChevronUp"


class HiOutlineCircleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCircleStack"


class HiOutlineClipboardDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineClipboardDocumentCheck"


class HiOutlineClipboardDocumentList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineClipboardDocumentList"


class HiOutlineClipboardDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineClipboardDocument"


class HiOutlineClipboard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineClipboard"


class HiOutlineClock(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineClock"


class HiOutlineCloudArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCloudArrowDown"


class HiOutlineCloudArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCloudArrowUp"


class HiOutlineCloud(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCloud"


class HiOutlineCodeBracketSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCodeBracketSquare"


class HiOutlineCodeBracket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCodeBracket"


class HiOutlineCog6Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCog6Tooth"


class HiOutlineCog8Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCog8Tooth"


class HiOutlineCog(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCog"


class HiOutlineCommandLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCommandLine"


class HiOutlineComputerDesktop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineComputerDesktop"


class HiOutlineCpuChip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCpuChip"


class HiOutlineCreditCard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCreditCard"


class HiOutlineCubeTransparent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCubeTransparent"


class HiOutlineCube(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCube"


class HiOutlineCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyBangladeshi"


class HiOutlineCurrencyDollar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyDollar"


class HiOutlineCurrencyEuro(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyEuro"


class HiOutlineCurrencyPound(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyPound"


class HiOutlineCurrencyRupee(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyRupee"


class HiOutlineCurrencyYen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCurrencyYen"


class HiOutlineCursorArrowRays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCursorArrowRays"


class HiOutlineCursorArrowRipple(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineCursorArrowRipple"


class HiOutlineDevicePhoneMobile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDevicePhoneMobile"


class HiOutlineDeviceTablet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDeviceTablet"


class HiOutlineDocumentArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentArrowDown"


class HiOutlineDocumentArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentArrowUp"


class HiOutlineDocumentChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentChartBar"


class HiOutlineDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentCheck"


class HiOutlineDocumentDuplicate(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentDuplicate"


class HiOutlineDocumentMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentMagnifyingGlass"


class HiOutlineDocumentMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentMinus"


class HiOutlineDocumentPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentPlus"


class HiOutlineDocumentText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocumentText"


class HiOutlineDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineDocument"


class HiOutlineEllipsisHorizontalCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEllipsisHorizontalCircle"


class HiOutlineEllipsisHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEllipsisHorizontal"


class HiOutlineEllipsisVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEllipsisVertical"


class HiOutlineEnvelopeOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEnvelopeOpen"


class HiOutlineEnvelope(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEnvelope"


class HiOutlineExclamationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineExclamationCircle"


class HiOutlineExclamationTriangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineExclamationTriangle"


class HiOutlineEyeDropper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEyeDropper"


class HiOutlineEyeSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEyeSlash"


class HiOutlineEye(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineEye"


class HiOutlineFaceFrown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFaceFrown"


class HiOutlineFaceSmile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFaceSmile"


class HiOutlineFilm(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFilm"


class HiOutlineFingerPrint(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFingerPrint"


class HiOutlineFire(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFire"


class HiOutlineFlag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFlag"


class HiOutlineFolderArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFolderArrowDown"


class HiOutlineFolderMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFolderMinus"


class HiOutlineFolderOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFolderOpen"


class HiOutlineFolderPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFolderPlus"


class HiOutlineFolder(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFolder"


class HiOutlineForward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineForward"


class HiOutlineFunnel(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineFunnel"


class HiOutlineGif(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGif"


class HiOutlineGiftTop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGiftTop"


class HiOutlineGift(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGift"


class HiOutlineGlobeAlt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGlobeAlt"


class HiOutlineGlobeAmericas(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGlobeAmericas"


class HiOutlineGlobeAsiaAustralia(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGlobeAsiaAustralia"


class HiOutlineGlobeEuropeAfrica(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineGlobeEuropeAfrica"


class HiOutlineHandRaised(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHandRaised"


class HiOutlineHandThumbDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHandThumbDown"


class HiOutlineHandThumbUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHandThumbUp"


class HiOutlineHashtag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHashtag"


class HiOutlineHeart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHeart"


class HiOutlineHomeModern(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHomeModern"


class HiOutlineHome(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineHome"


class HiOutlineIdentification(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineIdentification"


class HiOutlineInboxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineInboxArrowDown"


class HiOutlineInboxStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineInboxStack"


class HiOutlineInbox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineInbox"


class HiOutlineInformationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineInformationCircle"


class HiOutlineKey(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineKey"


class HiOutlineLanguage(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLanguage"


class HiOutlineLifebuoy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLifebuoy"


class HiOutlineLightBulb(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLightBulb"


class HiOutlineLink(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLink"


class HiOutlineListBullet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineListBullet"


class HiOutlineLockClosed(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLockClosed"


class HiOutlineLockOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineLockOpen"


class HiOutlineMagnifyingGlassCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMagnifyingGlassCircle"


class HiOutlineMagnifyingGlassMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMagnifyingGlassMinus"


class HiOutlineMagnifyingGlassPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMagnifyingGlassPlus"


class HiOutlineMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMagnifyingGlass"


class HiOutlineMapPin(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMapPin"


class HiOutlineMap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMap"


class HiOutlineMegaphone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMegaphone"


class HiOutlineMicrophone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMicrophone"


class HiOutlineMinusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMinusCircle"


class HiOutlineMinusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMinusSmall"


class HiOutlineMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMinus"


class HiOutlineMoon(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMoon"


class HiOutlineMusicalNote(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineMusicalNote"


class HiOutlineNewspaper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineNewspaper"


class HiOutlineNoSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineNoSymbol"


class HiOutlinePaintBrush(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePaintBrush"


class HiOutlinePaperAirplane(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePaperAirplane"


class HiOutlinePaperClip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePaperClip"


class HiOutlinePauseCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePauseCircle"


class HiOutlinePause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePause"


class HiOutlinePencilSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePencilSquare"


class HiOutlinePencil(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePencil"


class HiOutlinePhoneArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePhoneArrowDownLeft"


class HiOutlinePhoneArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePhoneArrowUpRight"


class HiOutlinePhoneXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePhoneXMark"


class HiOutlinePhone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePhone"


class HiOutlinePhoto(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePhoto"


class HiOutlinePlayCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlayCircle"


class HiOutlinePlayPause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlayPause"


class HiOutlinePlay(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlay"


class HiOutlinePlusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlusCircle"


class HiOutlinePlusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlusSmall"


class HiOutlinePlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePlus"


class HiOutlinePower(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePower"


class HiOutlinePresentationChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePresentationChartBar"


class HiOutlinePresentationChartLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePresentationChartLine"


class HiOutlinePrinter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePrinter"


class HiOutlinePuzzlePiece(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlinePuzzlePiece"


class HiOutlineQrCode(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineQrCode"


class HiOutlineQuestionMarkCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineQuestionMarkCircle"


class HiOutlineQueueList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineQueueList"


class HiOutlineRadio(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineRadio"


class HiOutlineReceiptPercent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineReceiptPercent"


class HiOutlineReceiptRefund(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineReceiptRefund"


class HiOutlineRectangleGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineRectangleGroup"


class HiOutlineRectangleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineRectangleStack"


class HiOutlineRocketLaunch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineRocketLaunch"


class HiOutlineRss(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineRss"


class HiOutlineScale(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineScale"


class HiOutlineScissors(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineScissors"


class HiOutlineServerStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineServerStack"


class HiOutlineServer(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineServer"


class HiOutlineShare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineShare"


class HiOutlineShieldCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineShieldCheck"


class HiOutlineShieldExclamation(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineShieldExclamation"


class HiOutlineShoppingBag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineShoppingBag"


class HiOutlineShoppingCart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineShoppingCart"


class HiOutlineSignalSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSignalSlash"


class HiOutlineSignal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSignal"


class HiOutlineSparkles(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSparkles"


class HiOutlineSpeakerWave(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSpeakerWave"


class HiOutlineSpeakerXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSpeakerXMark"


class HiOutlineSquare2Stack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSquare2Stack"


class HiOutlineSquare3Stack3D(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSquare3Stack3D"


class HiOutlineSquares2X2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSquares2X2"


class HiOutlineSquaresPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSquaresPlus"


class HiOutlineStar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineStar"


class HiOutlineStopCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineStopCircle"


class HiOutlineStop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineStop"


class HiOutlineSun(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSun"


class HiOutlineSwatch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineSwatch"


class HiOutlineTableCells(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTableCells"


class HiOutlineTag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTag"


class HiOutlineTicket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTicket"


class HiOutlineTrash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTrash"


class HiOutlineTrophy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTrophy"


class HiOutlineTruck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTruck"


class HiOutlineTv(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineTv"


class HiOutlineUserCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUserCircle"


class HiOutlineUserGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUserGroup"


class HiOutlineUserMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUserMinus"


class HiOutlineUserPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUserPlus"


class HiOutlineUser(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUser"


class HiOutlineUsers(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineUsers"


class HiOutlineVariable(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineVariable"


class HiOutlineVideoCameraSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineVideoCameraSlash"


class HiOutlineVideoCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineVideoCamera"


class HiOutlineViewColumns(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineViewColumns"


class HiOutlineViewfinderCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineViewfinderCircle"


class HiOutlineWallet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineWallet"


class HiOutlineWifi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineWifi"


class HiOutlineWindow(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineWindow"


class HiOutlineWrenchScrewdriver(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineWrenchScrewdriver"


class HiOutlineWrench(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineWrench"


class HiOutlineXCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineXCircle"


class HiOutlineXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiOutlineXMark"


class HiMiniAcademicCap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniAcademicCap"


class HiMiniAdjustmentsHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniAdjustmentsHorizontal"


class HiMiniAdjustmentsVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniAdjustmentsVertical"


class HiMiniArchiveBoxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArchiveBoxArrowDown"


class HiMiniArchiveBoxXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArchiveBoxXMark"


class HiMiniArchiveBox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArchiveBox"


class HiMiniArrowDownCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownCircle"


class HiMiniArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownLeft"


class HiMiniArrowDownOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownOnSquareStack"


class HiMiniArrowDownOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownOnSquare"


class HiMiniArrowDownRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownRight"


class HiMiniArrowDownTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDownTray"


class HiMiniArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowDown"


class HiMiniArrowLeftCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLeftCircle"


class HiMiniArrowLeftOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLeftOnRectangle"


class HiMiniArrowLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLeft"


class HiMiniArrowLongDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLongDown"


class HiMiniArrowLongLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLongLeft"


class HiMiniArrowLongRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLongRight"


class HiMiniArrowLongUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowLongUp"


class HiMiniArrowPathRoundedSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowPathRoundedSquare"


class HiMiniArrowPath(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowPath"


class HiMiniArrowRightCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowRightCircle"


class HiMiniArrowRightOnRectangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowRightOnRectangle"


class HiMiniArrowRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowRight"


class HiMiniArrowSmallDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowSmallDown"


class HiMiniArrowSmallLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowSmallLeft"


class HiMiniArrowSmallRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowSmallRight"


class HiMiniArrowSmallUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowSmallUp"


class HiMiniArrowTopRightOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowTopRightOnSquare"


class HiMiniArrowTrendingDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowTrendingDown"


class HiMiniArrowTrendingUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowTrendingUp"


class HiMiniArrowUpCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpCircle"


class HiMiniArrowUpLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpLeft"


class HiMiniArrowUpOnSquareStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpOnSquareStack"


class HiMiniArrowUpOnSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpOnSquare"


class HiMiniArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpRight"


class HiMiniArrowUpTray(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUpTray"


class HiMiniArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUp"


class HiMiniArrowUturnDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUturnDown"


class HiMiniArrowUturnLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUturnLeft"


class HiMiniArrowUturnRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUturnRight"


class HiMiniArrowUturnUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowUturnUp"


class HiMiniArrowsPointingIn(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowsPointingIn"


class HiMiniArrowsPointingOut(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowsPointingOut"


class HiMiniArrowsRightLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowsRightLeft"


class HiMiniArrowsUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniArrowsUpDown"


class HiMiniAtSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniAtSymbol"


class HiMiniBackspace(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBackspace"


class HiMiniBackward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBackward"


class HiMiniBanknotes(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBanknotes"


class HiMiniBars2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars2"


class HiMiniBars3BottomLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars3BottomLeft"


class HiMiniBars3BottomRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars3BottomRight"


class HiMiniBars3CenterLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars3CenterLeft"


class HiMiniBars3(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars3"


class HiMiniBars4(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBars4"


class HiMiniBarsArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBarsArrowDown"


class HiMiniBarsArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBarsArrowUp"


class HiMiniBattery0(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBattery0"


class HiMiniBattery100(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBattery100"


class HiMiniBattery50(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBattery50"


class HiMiniBeaker(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBeaker"


class HiMiniBellAlert(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBellAlert"


class HiMiniBellSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBellSlash"


class HiMiniBellSnooze(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBellSnooze"


class HiMiniBell(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBell"


class HiMiniBoltSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBoltSlash"


class HiMiniBolt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBolt"


class HiMiniBookOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBookOpen"


class HiMiniBookmarkSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBookmarkSlash"


class HiMiniBookmarkSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBookmarkSquare"


class HiMiniBookmark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBookmark"


class HiMiniBriefcase(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBriefcase"


class HiMiniBugAnt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBugAnt"


class HiMiniBuildingLibrary(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBuildingLibrary"


class HiMiniBuildingOffice2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBuildingOffice2"


class HiMiniBuildingOffice(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBuildingOffice"


class HiMiniBuildingStorefront(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniBuildingStorefront"


class HiMiniCake(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCake"


class HiMiniCalculator(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCalculator"


class HiMiniCalendarDays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCalendarDays"


class HiMiniCalendar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCalendar"


class HiMiniCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCamera"


class HiMiniChartBarSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChartBarSquare"


class HiMiniChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChartBar"


class HiMiniChartPie(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChartPie"


class HiMiniChatBubbleBottomCenterText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleBottomCenterText"


class HiMiniChatBubbleBottomCenter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleBottomCenter"


class HiMiniChatBubbleLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleLeftEllipsis"


class HiMiniChatBubbleLeftRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleLeftRight"


class HiMiniChatBubbleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleLeft"


class HiMiniChatBubbleOvalLeftEllipsis(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleOvalLeftEllipsis"


class HiMiniChatBubbleOvalLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChatBubbleOvalLeft"


class HiMiniCheckBadge(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCheckBadge"


class HiMiniCheckCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCheckCircle"


class HiMiniCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCheck"


class HiMiniChevronDoubleDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronDoubleDown"


class HiMiniChevronDoubleLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronDoubleLeft"


class HiMiniChevronDoubleRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronDoubleRight"


class HiMiniChevronDoubleUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronDoubleUp"


class HiMiniChevronDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronDown"


class HiMiniChevronLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronLeft"


class HiMiniChevronRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronRight"


class HiMiniChevronUpDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronUpDown"


class HiMiniChevronUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniChevronUp"


class HiMiniCircleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCircleStack"


class HiMiniClipboardDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniClipboardDocumentCheck"


class HiMiniClipboardDocumentList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniClipboardDocumentList"


class HiMiniClipboardDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniClipboardDocument"


class HiMiniClipboard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniClipboard"


class HiMiniClock(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniClock"


class HiMiniCloudArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCloudArrowDown"


class HiMiniCloudArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCloudArrowUp"


class HiMiniCloud(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCloud"


class HiMiniCodeBracketSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCodeBracketSquare"


class HiMiniCodeBracket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCodeBracket"


class HiMiniCog6Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCog6Tooth"


class HiMiniCog8Tooth(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCog8Tooth"


class HiMiniCog(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCog"


class HiMiniCommandLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCommandLine"


class HiMiniComputerDesktop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniComputerDesktop"


class HiMiniCpuChip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCpuChip"


class HiMiniCreditCard(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCreditCard"


class HiMiniCubeTransparent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCubeTransparent"


class HiMiniCube(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCube"


class HiMiniCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyBangladeshi"


class HiMiniCurrencyDollar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyDollar"


class HiMiniCurrencyEuro(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyEuro"


class HiMiniCurrencyPound(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyPound"


class HiMiniCurrencyRupee(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyRupee"


class HiMiniCurrencyYen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCurrencyYen"


class HiMiniCursorArrowRays(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCursorArrowRays"


class HiMiniCursorArrowRipple(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniCursorArrowRipple"


class HiMiniDevicePhoneMobile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDevicePhoneMobile"


class HiMiniDeviceTablet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDeviceTablet"


class HiMiniDocumentArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentArrowDown"


class HiMiniDocumentArrowUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentArrowUp"


class HiMiniDocumentChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentChartBar"


class HiMiniDocumentCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentCheck"


class HiMiniDocumentDuplicate(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentDuplicate"


class HiMiniDocumentMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentMagnifyingGlass"


class HiMiniDocumentMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentMinus"


class HiMiniDocumentPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentPlus"


class HiMiniDocumentText(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocumentText"


class HiMiniDocument(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniDocument"


class HiMiniEllipsisHorizontalCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEllipsisHorizontalCircle"


class HiMiniEllipsisHorizontal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEllipsisHorizontal"


class HiMiniEllipsisVertical(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEllipsisVertical"


class HiMiniEnvelopeOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEnvelopeOpen"


class HiMiniEnvelope(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEnvelope"


class HiMiniExclamationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniExclamationCircle"


class HiMiniExclamationTriangle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniExclamationTriangle"


class HiMiniEyeDropper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEyeDropper"


class HiMiniEyeSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEyeSlash"


class HiMiniEye(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniEye"


class HiMiniFaceFrown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFaceFrown"


class HiMiniFaceSmile(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFaceSmile"


class HiMiniFilm(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFilm"


class HiMiniFingerPrint(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFingerPrint"


class HiMiniFire(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFire"


class HiMiniFlag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFlag"


class HiMiniFolderArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFolderArrowDown"


class HiMiniFolderMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFolderMinus"


class HiMiniFolderOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFolderOpen"


class HiMiniFolderPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFolderPlus"


class HiMiniFolder(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFolder"


class HiMiniForward(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniForward"


class HiMiniFunnel(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniFunnel"


class HiMiniGif(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGif"


class HiMiniGiftTop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGiftTop"


class HiMiniGift(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGift"


class HiMiniGlobeAlt(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGlobeAlt"


class HiMiniGlobeAmericas(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGlobeAmericas"


class HiMiniGlobeAsiaAustralia(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGlobeAsiaAustralia"


class HiMiniGlobeEuropeAfrica(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniGlobeEuropeAfrica"


class HiMiniHandRaised(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHandRaised"


class HiMiniHandThumbDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHandThumbDown"


class HiMiniHandThumbUp(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHandThumbUp"


class HiMiniHashtag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHashtag"


class HiMiniHeart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHeart"


class HiMiniHomeModern(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHomeModern"


class HiMiniHome(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniHome"


class HiMiniIdentification(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniIdentification"


class HiMiniInboxArrowDown(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniInboxArrowDown"


class HiMiniInboxStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniInboxStack"


class HiMiniInbox(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniInbox"


class HiMiniInformationCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniInformationCircle"


class HiMiniKey(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniKey"


class HiMiniLanguage(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLanguage"


class HiMiniLifebuoy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLifebuoy"


class HiMiniLightBulb(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLightBulb"


class HiMiniLink(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLink"


class HiMiniListBullet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniListBullet"


class HiMiniLockClosed(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLockClosed"


class HiMiniLockOpen(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniLockOpen"


class HiMiniMagnifyingGlassCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMagnifyingGlassCircle"


class HiMiniMagnifyingGlassMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMagnifyingGlassMinus"


class HiMiniMagnifyingGlassPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMagnifyingGlassPlus"


class HiMiniMagnifyingGlass(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMagnifyingGlass"


class HiMiniMapPin(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMapPin"


class HiMiniMap(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMap"


class HiMiniMegaphone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMegaphone"


class HiMiniMicrophone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMicrophone"


class HiMiniMinusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMinusCircle"


class HiMiniMinusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMinusSmall"


class HiMiniMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMinus"


class HiMiniMoon(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMoon"


class HiMiniMusicalNote(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniMusicalNote"


class HiMiniNewspaper(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniNewspaper"


class HiMiniNoSymbol(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniNoSymbol"


class HiMiniPaintBrush(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPaintBrush"


class HiMiniPaperAirplane(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPaperAirplane"


class HiMiniPaperClip(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPaperClip"


class HiMiniPauseCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPauseCircle"


class HiMiniPause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPause"


class HiMiniPencilSquare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPencilSquare"


class HiMiniPencil(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPencil"


class HiMiniPhoneArrowDownLeft(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPhoneArrowDownLeft"


class HiMiniPhoneArrowUpRight(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPhoneArrowUpRight"


class HiMiniPhoneXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPhoneXMark"


class HiMiniPhone(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPhone"


class HiMiniPhoto(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPhoto"


class HiMiniPlayCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlayCircle"


class HiMiniPlayPause(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlayPause"


class HiMiniPlay(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlay"


class HiMiniPlusCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlusCircle"


class HiMiniPlusSmall(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlusSmall"


class HiMiniPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPlus"


class HiMiniPower(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPower"


class HiMiniPresentationChartBar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPresentationChartBar"


class HiMiniPresentationChartLine(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPresentationChartLine"


class HiMiniPrinter(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPrinter"


class HiMiniPuzzlePiece(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniPuzzlePiece"


class HiMiniQrCode(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniQrCode"


class HiMiniQuestionMarkCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniQuestionMarkCircle"


class HiMiniQueueList(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniQueueList"


class HiMiniRadio(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniRadio"


class HiMiniReceiptPercent(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniReceiptPercent"


class HiMiniReceiptRefund(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniReceiptRefund"


class HiMiniRectangleGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniRectangleGroup"


class HiMiniRectangleStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniRectangleStack"


class HiMiniRocketLaunch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniRocketLaunch"


class HiMiniRss(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniRss"


class HiMiniScale(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniScale"


class HiMiniScissors(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniScissors"


class HiMiniServerStack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniServerStack"


class HiMiniServer(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniServer"


class HiMiniShare(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniShare"


class HiMiniShieldCheck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniShieldCheck"


class HiMiniShieldExclamation(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniShieldExclamation"


class HiMiniShoppingBag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniShoppingBag"


class HiMiniShoppingCart(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniShoppingCart"


class HiMiniSignalSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSignalSlash"


class HiMiniSignal(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSignal"


class HiMiniSparkles(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSparkles"


class HiMiniSpeakerWave(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSpeakerWave"


class HiMiniSpeakerXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSpeakerXMark"


class HiMiniSquare2Stack(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSquare2Stack"


class HiMiniSquare3Stack3D(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSquare3Stack3D"


class HiMiniSquares2X2(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSquares2X2"


class HiMiniSquaresPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSquaresPlus"


class HiMiniStar(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniStar"


class HiMiniStopCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniStopCircle"


class HiMiniStop(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniStop"


class HiMiniSun(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSun"


class HiMiniSwatch(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniSwatch"


class HiMiniTableCells(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTableCells"


class HiMiniTag(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTag"


class HiMiniTicket(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTicket"


class HiMiniTrash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTrash"


class HiMiniTrophy(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTrophy"


class HiMiniTruck(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTruck"


class HiMiniTv(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniTv"


class HiMiniUserCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUserCircle"


class HiMiniUserGroup(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUserGroup"


class HiMiniUserMinus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUserMinus"


class HiMiniUserPlus(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUserPlus"


class HiMiniUser(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUser"


class HiMiniUsers(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniUsers"


class HiMiniVariable(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniVariable"


class HiMiniVideoCameraSlash(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniVideoCameraSlash"


class HiMiniVideoCamera(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniVideoCamera"


class HiMiniViewColumns(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniViewColumns"


class HiMiniViewfinderCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniViewfinderCircle"


class HiMiniWallet(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniWallet"


class HiMiniWifi(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniWifi"


class HiMiniWindow(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniWindow"


class HiMiniWrenchScrewdriver(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniWrenchScrewdriver"


class HiMiniWrench(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniWrench"


class HiMiniXCircle(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniXCircle"


class HiMiniXMark(rx.Component):
    library = "react-icons/hi2"
    tag = "HiMiniXMark"





import reflex as rx

class DiAndroid(rx.Component):
    library = "react-icons/di"
    tag = "DiAndroid"


class DiAngularSimple(rx.Component):
    library = "react-icons/di"
    tag = "DiAngularSimple"


class DiAppcelerator(rx.Component):
    library = "react-icons/di"
    tag = "DiAppcelerator"


class DiApple(rx.Component):
    library = "react-icons/di"
    tag = "DiApple"


class DiAppstore(rx.Component):
    library = "react-icons/di"
    tag = "DiAppstore"


class DiAptana(rx.Component):
    library = "react-icons/di"
    tag = "DiAptana"


class DiAsterisk(rx.Component):
    library = "react-icons/di"
    tag = "DiAsterisk"


class DiAtlassian(rx.Component):
    library = "react-icons/di"
    tag = "DiAtlassian"


class DiAtom(rx.Component):
    library = "react-icons/di"
    tag = "DiAtom"


class DiAws(rx.Component):
    library = "react-icons/di"
    tag = "DiAws"


class DiBackbone(rx.Component):
    library = "react-icons/di"
    tag = "DiBackbone"


class DiBingSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiBingSmall"


class DiBintray(rx.Component):
    library = "react-icons/di"
    tag = "DiBintray"


class DiBitbucket(rx.Component):
    library = "react-icons/di"
    tag = "DiBitbucket"


class DiBlackberry(rx.Component):
    library = "react-icons/di"
    tag = "DiBlackberry"


class DiBootstrap(rx.Component):
    library = "react-icons/di"
    tag = "DiBootstrap"


class DiBower(rx.Component):
    library = "react-icons/di"
    tag = "DiBower"


class DiBrackets(rx.Component):
    library = "react-icons/di"
    tag = "DiBrackets"


class DiBugsense(rx.Component):
    library = "react-icons/di"
    tag = "DiBugsense"


class DiCelluloid(rx.Component):
    library = "react-icons/di"
    tag = "DiCelluloid"


class DiChrome(rx.Component):
    library = "react-icons/di"
    tag = "DiChrome"


class DiCisco(rx.Component):
    library = "react-icons/di"
    tag = "DiCisco"


class DiClojureAlt(rx.Component):
    library = "react-icons/di"
    tag = "DiClojureAlt"


class DiClojure(rx.Component):
    library = "react-icons/di"
    tag = "DiClojure"


class DiCloud9(rx.Component):
    library = "react-icons/di"
    tag = "DiCloud9"


class DiCoda(rx.Component):
    library = "react-icons/di"
    tag = "DiCoda"


class DiCodeBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiCodeBadge"


class DiCode(rx.Component):
    library = "react-icons/di"
    tag = "DiCode"


class DiCodeigniter(rx.Component):
    library = "react-icons/di"
    tag = "DiCodeigniter"


class DiCodepen(rx.Component):
    library = "react-icons/di"
    tag = "DiCodepen"


class DiCodrops(rx.Component):
    library = "react-icons/di"
    tag = "DiCodrops"


class DiCoffeescript(rx.Component):
    library = "react-icons/di"
    tag = "DiCoffeescript"


class DiCompass(rx.Component):
    library = "react-icons/di"
    tag = "DiCompass"


class DiComposer(rx.Component):
    library = "react-icons/di"
    tag = "DiComposer"


class DiCreativecommonsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiCreativecommonsBadge"


class DiCreativecommons(rx.Component):
    library = "react-icons/di"
    tag = "DiCreativecommons"


class DiCssTricks(rx.Component):
    library = "react-icons/di"
    tag = "DiCssTricks"


class DiCss3Full(rx.Component):
    library = "react-icons/di"
    tag = "DiCss3Full"


class DiCss3(rx.Component):
    library = "react-icons/di"
    tag = "DiCss3"


class DiCssdeck(rx.Component):
    library = "react-icons/di"
    tag = "DiCssdeck"


class DiDart(rx.Component):
    library = "react-icons/di"
    tag = "DiDart"


class DiDatabase(rx.Component):
    library = "react-icons/di"
    tag = "DiDatabase"


class DiDebian(rx.Component):
    library = "react-icons/di"
    tag = "DiDebian"


class DiDigitalOcean(rx.Component):
    library = "react-icons/di"
    tag = "DiDigitalOcean"


class DiDjango(rx.Component):
    library = "react-icons/di"
    tag = "DiDjango"


class DiDlang(rx.Component):
    library = "react-icons/di"
    tag = "DiDlang"


class DiDocker(rx.Component):
    library = "react-icons/di"
    tag = "DiDocker"


class DiDoctrine(rx.Component):
    library = "react-icons/di"
    tag = "DiDoctrine"


class DiDojo(rx.Component):
    library = "react-icons/di"
    tag = "DiDojo"


class DiDotnet(rx.Component):
    library = "react-icons/di"
    tag = "DiDotnet"


class DiDreamweaver(rx.Component):
    library = "react-icons/di"
    tag = "DiDreamweaver"


class DiDropbox(rx.Component):
    library = "react-icons/di"
    tag = "DiDropbox"


class DiDrupal(rx.Component):
    library = "react-icons/di"
    tag = "DiDrupal"


class DiEclipse(rx.Component):
    library = "react-icons/di"
    tag = "DiEclipse"


class DiEmber(rx.Component):
    library = "react-icons/di"
    tag = "DiEmber"


class DiEnvato(rx.Component):
    library = "react-icons/di"
    tag = "DiEnvato"


class DiErlang(rx.Component):
    library = "react-icons/di"
    tag = "DiErlang"


class DiExtjs(rx.Component):
    library = "react-icons/di"
    tag = "DiExtjs"


class DiFirebase(rx.Component):
    library = "react-icons/di"
    tag = "DiFirebase"


class DiFirefox(rx.Component):
    library = "react-icons/di"
    tag = "DiFirefox"


class DiFsharp(rx.Component):
    library = "react-icons/di"
    tag = "DiFsharp"


class DiGhostSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiGhostSmall"


class DiGhost(rx.Component):
    library = "react-icons/di"
    tag = "DiGhost"


class DiGitBranch(rx.Component):
    library = "react-icons/di"
    tag = "DiGitBranch"


class DiGitCommit(rx.Component):
    library = "react-icons/di"
    tag = "DiGitCommit"


class DiGitCompare(rx.Component):
    library = "react-icons/di"
    tag = "DiGitCompare"


class DiGitMerge(rx.Component):
    library = "react-icons/di"
    tag = "DiGitMerge"


class DiGitPullRequest(rx.Component):
    library = "react-icons/di"
    tag = "DiGitPullRequest"


class DiGit(rx.Component):
    library = "react-icons/di"
    tag = "DiGit"


class DiGithubAlt(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubAlt"


class DiGithubBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubBadge"


class DiGithubFull(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubFull"


class DiGithub(rx.Component):
    library = "react-icons/di"
    tag = "DiGithub"


class DiGnu(rx.Component):
    library = "react-icons/di"
    tag = "DiGnu"


class DiGo(rx.Component):
    library = "react-icons/di"
    tag = "DiGo"


class DiGoogleAnalytics(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleAnalytics"


class DiGoogleDrive(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleDrive"


class DiGoogleCloudPlatform(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleCloudPlatform"


class DiGrails(rx.Component):
    library = "react-icons/di"
    tag = "DiGrails"


class DiGroovy(rx.Component):
    library = "react-icons/di"
    tag = "DiGroovy"


class DiGrunt(rx.Component):
    library = "react-icons/di"
    tag = "DiGrunt"


class DiGulp(rx.Component):
    library = "react-icons/di"
    tag = "DiGulp"


class DiHackernews(rx.Component):
    library = "react-icons/di"
    tag = "DiHackernews"


class DiHaskell(rx.Component):
    library = "react-icons/di"
    tag = "DiHaskell"


class DiHeroku(rx.Component):
    library = "react-icons/di"
    tag = "DiHeroku"


class DiHtml53DEffects(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml53DEffects"


class DiHtml5Connectivity(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5Connectivity"


class DiHtml5DeviceAccess(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5DeviceAccess"


class DiHtml5Multimedia(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5Multimedia"


class DiHtml5(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5"


class DiIe(rx.Component):
    library = "react-icons/di"
    tag = "DiIe"


class DiIllustrator(rx.Component):
    library = "react-icons/di"
    tag = "DiIllustrator"


class DiIntellij(rx.Component):
    library = "react-icons/di"
    tag = "DiIntellij"


class DiIonic(rx.Component):
    library = "react-icons/di"
    tag = "DiIonic"


class DiJava(rx.Component):
    library = "react-icons/di"
    tag = "DiJava"


class DiJavascript1(rx.Component):
    library = "react-icons/di"
    tag = "DiJavascript1"


class DiJavascript(rx.Component):
    library = "react-icons/di"
    tag = "DiJavascript"


class DiJekyllSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiJekyllSmall"


class DiJenkins(rx.Component):
    library = "react-icons/di"
    tag = "DiJenkins"


class DiJira(rx.Component):
    library = "react-icons/di"
    tag = "DiJira"


class DiJoomla(rx.Component):
    library = "react-icons/di"
    tag = "DiJoomla"


class DiJqueryLogo(rx.Component):
    library = "react-icons/di"
    tag = "DiJqueryLogo"


class DiJqueryUiLogo(rx.Component):
    library = "react-icons/di"
    tag = "DiJqueryUiLogo"


class DiJsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiJsBadge"


class DiKomodo(rx.Component):
    library = "react-icons/di"
    tag = "DiKomodo"


class DiKrakenjsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiKrakenjsBadge"


class DiKrakenjs(rx.Component):
    library = "react-icons/di"
    tag = "DiKrakenjs"


class DiLaravel(rx.Component):
    library = "react-icons/di"
    tag = "DiLaravel"


class DiLess(rx.Component):
    library = "react-icons/di"
    tag = "DiLess"


class DiLinux(rx.Component):
    library = "react-icons/di"
    tag = "DiLinux"


class DiMagento(rx.Component):
    library = "react-icons/di"
    tag = "DiMagento"


class DiMailchimp(rx.Component):
    library = "react-icons/di"
    tag = "DiMailchimp"


class DiMarkdown(rx.Component):
    library = "react-icons/di"
    tag = "DiMarkdown"


class DiMaterializecss(rx.Component):
    library = "react-icons/di"
    tag = "DiMaterializecss"


class DiMeteor(rx.Component):
    library = "react-icons/di"
    tag = "DiMeteor"


class DiMeteorfull(rx.Component):
    library = "react-icons/di"
    tag = "DiMeteorfull"


class DiMitlicence(rx.Component):
    library = "react-icons/di"
    tag = "DiMitlicence"


class DiModernizr(rx.Component):
    library = "react-icons/di"
    tag = "DiModernizr"


class DiMongodb(rx.Component):
    library = "react-icons/di"
    tag = "DiMongodb"


class DiMootoolsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiMootoolsBadge"


class DiMootools(rx.Component):
    library = "react-icons/di"
    tag = "DiMootools"


class DiMozilla(rx.Component):
    library = "react-icons/di"
    tag = "DiMozilla"


class DiMsqlServer(rx.Component):
    library = "react-icons/di"
    tag = "DiMsqlServer"


class DiMysql(rx.Component):
    library = "react-icons/di"
    tag = "DiMysql"


class DiNancy(rx.Component):
    library = "react-icons/di"
    tag = "DiNancy"


class DiNetbeans(rx.Component):
    library = "react-icons/di"
    tag = "DiNetbeans"


class DiNetmagazine(rx.Component):
    library = "react-icons/di"
    tag = "DiNetmagazine"


class DiNginx(rx.Component):
    library = "react-icons/di"
    tag = "DiNginx"


class DiNodejsSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiNodejsSmall"


class DiNodejs(rx.Component):
    library = "react-icons/di"
    tag = "DiNodejs"


class DiNpm(rx.Component):
    library = "react-icons/di"
    tag = "DiNpm"


class DiOnedrive(rx.Component):
    library = "react-icons/di"
    tag = "DiOnedrive"


class DiOpenshift(rx.Component):
    library = "react-icons/di"
    tag = "DiOpenshift"


class DiOpensource(rx.Component):
    library = "react-icons/di"
    tag = "DiOpensource"


class DiOpera(rx.Component):
    library = "react-icons/di"
    tag = "DiOpera"


class DiPerl(rx.Component):
    library = "react-icons/di"
    tag = "DiPerl"


class DiPhonegap(rx.Component):
    library = "react-icons/di"
    tag = "DiPhonegap"


class DiPhotoshop(rx.Component):
    library = "react-icons/di"
    tag = "DiPhotoshop"


class DiPhp(rx.Component):
    library = "react-icons/di"
    tag = "DiPhp"


class DiPostgresql(rx.Component):
    library = "react-icons/di"
    tag = "DiPostgresql"


class DiProlog(rx.Component):
    library = "react-icons/di"
    tag = "DiProlog"


class DiPython(rx.Component):
    library = "react-icons/di"
    tag = "DiPython"


class DiRackspace(rx.Component):
    library = "react-icons/di"
    tag = "DiRackspace"


class DiRaphael(rx.Component):
    library = "react-icons/di"
    tag = "DiRaphael"


class DiRasberryPi(rx.Component):
    library = "react-icons/di"
    tag = "DiRasberryPi"


class DiReact(rx.Component):
    library = "react-icons/di"
    tag = "DiReact"


class DiRedhat(rx.Component):
    library = "react-icons/di"
    tag = "DiRedhat"


class DiRedis(rx.Component):
    library = "react-icons/di"
    tag = "DiRedis"


class DiRequirejs(rx.Component):
    library = "react-icons/di"
    tag = "DiRequirejs"


class DiResponsive(rx.Component):
    library = "react-icons/di"
    tag = "DiResponsive"


class DiRor(rx.Component):
    library = "react-icons/di"
    tag = "DiRor"


class DiRubyRough(rx.Component):
    library = "react-icons/di"
    tag = "DiRubyRough"


class DiRuby(rx.Component):
    library = "react-icons/di"
    tag = "DiRuby"


class DiRust(rx.Component):
    library = "react-icons/di"
    tag = "DiRust"


class DiSafari(rx.Component):
    library = "react-icons/di"
    tag = "DiSafari"


class DiSass(rx.Component):
    library = "react-icons/di"
    tag = "DiSass"


class DiScala(rx.Component):
    library = "react-icons/di"
    tag = "DiScala"


class DiScriptcs(rx.Component):
    library = "react-icons/di"
    tag = "DiScriptcs"


class DiScrum(rx.Component):
    library = "react-icons/di"
    tag = "DiScrum"


class DiSenchatouch(rx.Component):
    library = "react-icons/di"
    tag = "DiSenchatouch"


class DiSizzlejs(rx.Component):
    library = "react-icons/di"
    tag = "DiSizzlejs"


class DiSmashingMagazine(rx.Component):
    library = "react-icons/di"
    tag = "DiSmashingMagazine"


class DiSnapSvg(rx.Component):
    library = "react-icons/di"
    tag = "DiSnapSvg"


class DiSpark(rx.Component):
    library = "react-icons/di"
    tag = "DiSpark"


class DiSqllite(rx.Component):
    library = "react-icons/di"
    tag = "DiSqllite"


class DiStackoverflow(rx.Component):
    library = "react-icons/di"
    tag = "DiStackoverflow"


class DiStreamline(rx.Component):
    library = "react-icons/di"
    tag = "DiStreamline"


class DiStylus(rx.Component):
    library = "react-icons/di"
    tag = "DiStylus"


class DiSublime(rx.Component):
    library = "react-icons/di"
    tag = "DiSublime"


class DiSwift(rx.Component):
    library = "react-icons/di"
    tag = "DiSwift"


class DiSymfonyBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiSymfonyBadge"


class DiSymfony(rx.Component):
    library = "react-icons/di"
    tag = "DiSymfony"


class DiTechcrunch(rx.Component):
    library = "react-icons/di"
    tag = "DiTechcrunch"


class DiTerminalBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiTerminalBadge"


class DiTerminal(rx.Component):
    library = "react-icons/di"
    tag = "DiTerminal"


class DiTravis(rx.Component):
    library = "react-icons/di"
    tag = "DiTravis"


class DiTrello(rx.Component):
    library = "react-icons/di"
    tag = "DiTrello"


class DiTypo3(rx.Component):
    library = "react-icons/di"
    tag = "DiTypo3"


class DiUbuntu(rx.Component):
    library = "react-icons/di"
    tag = "DiUbuntu"


class DiUikit(rx.Component):
    library = "react-icons/di"
    tag = "DiUikit"


class DiUnitySmall(rx.Component):
    library = "react-icons/di"
    tag = "DiUnitySmall"


class DiVim(rx.Component):
    library = "react-icons/di"
    tag = "DiVim"


class DiVisualstudio(rx.Component):
    library = "react-icons/di"
    tag = "DiVisualstudio"


class DiW3C(rx.Component):
    library = "react-icons/di"
    tag = "DiW3C"


class DiWebplatform(rx.Component):
    library = "react-icons/di"
    tag = "DiWebplatform"


class DiWindows(rx.Component):
    library = "react-icons/di"
    tag = "DiWindows"


class DiWordpress(rx.Component):
    library = "react-icons/di"
    tag = "DiWordpress"


class DiYahooSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiYahooSmall"


class DiYahoo(rx.Component):
    library = "react-icons/di"
    tag = "DiYahoo"


class DiYeoman(rx.Component):
    library = "react-icons/di"
    tag = "DiYeoman"


class DiYii(rx.Component):
    library = "react-icons/di"
    tag = "DiYii"


class DiZend(rx.Component):
    library = "react-icons/di"
    tag = "DiZend"


